@@ -15,7 +15,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.14.0";
+our $VERSION = "v6.15.0";
 
 1;
 __END__
@@ -61,7 +61,7 @@ The documentation in this POD applies to all three adapter modules as well.
 This module is an implementation of L<Reactive Extensions|http://reactivex.io/> in Perl. It replicates the
 behavior of L<rxjs 6|https://www.npmjs.com/package/rxjs> which is the JavaScript implementation of ReactiveX.
 
-Currently 58 of the 100+ operators in rxjs are implemented in this module.
+Currently 63 of the 100+ operators in rxjs are implemented in this module.
 
 =head1 EXPORTABLE FUNCTIONS
 
@@ -278,6 +278,13 @@ L<https://rxjs.dev/api/index/function/race>
         rx_interval(0.7)->pipe( op_map(sub {$_[0] * 10) ),
     )->subscribe($observer);
 
+=item rx_range
+
+L<https://rxjs.dev/api/index/function/range>
+
+    # 10, 11, 12, 13, 14, 15, 16, complete
+    rx_range(10, 7)->subscribe($observer);
+
 =item rx_replay_subject
 
 L<https://rxjs.dev/api/index/class/ReplaySubject>
@@ -381,6 +388,17 @@ L<https://rxjs.dev/api/operators/bufferCount>
         op_buffer_count(3, 1),
     )->subscribe($observer);
 
+=item op_buffer_time
+
+Works like rxjs's "bufferTime", except the parameter is in seconds instead of ms.
+
+L<https://rxjs.dev/api/operators/bufferTime>
+
+    # [0], [1], [2, 3], [4], [5, 6], [7]...
+    rx_interval(0.7)->pipe(
+        op_buffer_time(1),
+    )->subscribe($observer);
+
 =item op_catch_error
 
 L<https://rxjs.dev/api/operators/catchError>
@@ -417,6 +435,37 @@ L<https://rxjs.dev/api/operators/concatMap>
         }),
     )->subscribe($observer);
 
+=item op_concat_with
+
+L<https://rxjs.dev/api/operators/concatWith>
+
+    # 0, 1, 2, 3, 4, 5, 6, 7, 8, complete
+    rx_of(0, 1, 2)->pipe(
+        op_concat_with(
+            rx_of(3, 4, 5),
+            rx_of(6, 7, 8),
+        ),
+    )->subscribe($observer);
+
+=item op_count
+
+L<https://rxjs.dev/api/operators/count>
+
+    # 3, complete
+    rx_of(0, 1, 2)->pipe(
+        op_count(),
+    )->subscribe($observer);
+
+    # 3, complete
+    rx_of(0, 1, 2, 3, 4, 5, 6)->pipe(
+        op_count(sub { $_[0] % 2 == 1 }), # could have also used $_ here instead of $_[0]
+    )->subscribe($observer);
+
+    # 4, complete
+    rx_of(1, 1, 1, 1, 1, 1, 1)->pipe(
+        op_count(sub ($value, $idx) { $idx % 2 == 0 }),
+    );
+
 =item op_debounce_time
 
 L<https://rxjs.dev/api/operators/debounceTime>
@@ -428,6 +477,16 @@ Works like rxjs's "debounceTime", except the parameter is in seconds instead of
         op_debounce_time(0.5),
     )->subscribe($observer);
 
+=item op_default_if_empty
+
+L<https://rxjs.dev/api/operators/defaultIfEmpty>
+
+    # 42, complete
+    rx_timer(0.7)->pipe(
+        op_ignore_elements(),
+        op_default_if_empty(42),
+    )->subscribe($observer);
+
 =item op_delay
 
 L<https://rxjs.dev/api/operators/delay>
