@@ -14,14 +14,13 @@ use Scalar::Util qw/ weaken blessed reftype /;
 
 use Exporter 'import';
 our @EXPORT_OK = qw/
-    rx_behavior_subject rx_combine_latest rx_concat rx_defer rx_EMPTY
-    rx_fork_join rx_from rx_from_event rx_from_event_array rx_interval
-    rx_merge rx_NEVER rx_observable rx_of rx_partition rx_race
+    rx_behavior_subject rx_combine_latest rx_concat rx_defer rx_EMPTY rx_fork_join rx_from rx_from_event
+    rx_from_event_array rx_interval rx_merge rx_NEVER rx_observable rx_of rx_partition rx_race rx_range
     rx_replay_subject rx_subject rx_throw_error rx_timer
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.14.0";
+our $VERSION = "v6.15.0";
 
 sub rx_observable;
 
@@ -396,10 +395,14 @@ sub rx_of {
     return rx_observable->new(sub {
         my ($subscriber) = @_;
 
-        foreach my $value (@values) {
-            return if !! ${ $subscriber->{closed_ref} };
-            $subscriber->{next}->($value) if defined $subscriber->{next};
+        my $i = 0;
+
+        $subscriber->subscription->add(sub { $i = @values });
+
+        for (; $i < @values; $i++) {
+            $subscriber->{next}->($values[$i]) if defined $subscriber->{next};
         }
+
         $subscriber->{complete}->() if defined $subscriber->{complete};
 
         return;
@@ -464,6 +467,26 @@ sub rx_race {
     });
 }
 
+sub rx_range {
+    my ($start, $count) = @_;
+
+    return rx_observable->new(sub {
+        my ($subscriber) = @_;
+
+        my $i = $start;
+
+        $subscriber->subscription->add(sub { $i = $start + $count });
+
+        for (; $i < $start + $count; $i++) {
+            $subscriber->{next}->($i) if defined $subscriber->{next};
+        }
+
+        $subscriber->{complete}->() if defined $subscriber->{complete};
+
+        return;
+    });
+}
+
 sub rx_replay_subject { "RxPerl::ReplaySubject" }
 
 sub rx_subject { "RxPerl::Subject" }
