@@ -2,7 +2,9 @@ package RxPerl::Operators::Pipeable;
 use strict;
 use warnings;
 
-use RxPerl::Operators::Creation qw/ rx_observable rx_subject rx_concat rx_of rx_interval rx_combine_latest /;
+use RxPerl::Operators::Creation qw/
+    rx_observable rx_subject rx_concat rx_of rx_interval rx_combine_latest rx_concat
+/;
 use RxPerl::ConnectableObservable;
 use RxPerl::Utils qw/ get_timer_subs /;
 use RxPerl::Subscription;
@@ -12,15 +14,16 @@ use Scalar::Util 'reftype', 'refaddr', 'blessed', 'weaken';
 
 use Exporter 'import';
 our @EXPORT_OK = qw/
-    op_audit_time op_buffer op_buffer_count op_catch_error op_combine_latest_with op_concat_map op_debounce_time
-    op_delay op_distinct_until_changed op_distinct_until_key_changed op_end_with op_exhaust_map op_filter op_finalize
-    op_first op_ignore_elements op_map op_map_to op_merge_map op_multicast op_pairwise op_pluck op_ref_count op_repeat
-    op_retry op_sample_time op_scan op_share op_skip op_skip_until op_start_with op_switch_map op_take op_take_until
-    op_take_while op_tap op_throttle_time op_with_latest_from
+    op_audit_time op_buffer op_buffer_count op_buffer_time op_catch_error op_combine_latest_with op_concat_map
+    op_concat_with op_count op_debounce_time op_default_if_empty op_delay op_distinct_until_changed
+    op_distinct_until_key_changed op_end_with op_exhaust_map op_filter op_finalize op_first op_ignore_elements op_map
+    op_map_to op_merge_map op_multicast op_pairwise op_pluck op_ref_count op_repeat op_retry op_sample_time op_scan
+    op_share op_skip op_skip_until op_start_with op_switch_map op_take op_take_until op_take_while op_tap
+    op_throttle_time op_with_latest_from
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.14.0";
+our $VERSION = "v6.15.0";
 
 sub op_audit_time {
     my ($duration) = @_;
@@ -154,6 +157,39 @@ sub op_buffer_count {
     };
 }
 
+sub op_buffer_time {
+    my ($buffer_time_span) = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my @buffer;
+
+            my $si = rx_interval($buffer_time_span)->subscribe(
+                sub {
+                    $subscriber->{next}->([ @buffer ]) if defined $subscriber->{next};
+                    undef @buffer;
+                },
+            );
+
+            my $own_subscriber = {
+                %$subscriber,
+                next => sub {
+                    my ($v) = @_;
+                    push @buffer, $v;
+                },
+            };
+
+            $source->subscribe($own_subscriber);
+
+            return $si;
+        });
+    };
+}
+
 sub _op_catch_error_helper {
     my ($source, $selector, $subscriber, $dependents, $error) = @_;
 
@@ -286,6 +322,53 @@ sub op_concat_map {
     };
 }
 
+sub op_concat_with {
+    my @other_observables = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_concat(
+            $source,
+            @other_observables,
+        );
+    };
+}
+
+sub op_count {
+    my ($predicate) = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my $count = 0;
+            my $idx = 0;
+
+            my $own_subscriber = {
+                %$subscriber,
+                next     => sub {
+                    my ($v) = @_;
+                    local $_ = $v;
+                    if (!$predicate or $predicate->($v, $idx++)) {
+                        $count++;
+                    }
+                },
+                complete => sub {
+                    $subscriber->{next}->($count) if defined $subscriber->{next};
+                    $subscriber->{complete}->() if defined $subscriber->{complete};
+                },
+            };
+
+            $source->subscribe($own_subscriber);
+
+            return;
+        });
+    };
+}
+
 my $_debounce_empty = {};
 
 sub op_debounce_time {
@@ -337,6 +420,36 @@ sub op_debounce_time {
     }
 }
 
+sub op_default_if_empty {
+    my ($default_value) = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my $source_emitted = 0;
+
+            my $own_subscriber = {
+                %$subscriber,
+                next     => sub {
+                    $source_emitted = 1;
+                    $subscriber->{next}->(@_) if exists $subscriber->{next};
+                },
+                complete => sub {
+                    $subscriber->{next}->($default_value) if ! $source_emitted and exists $subscriber->{next};
+                    $subscriber->{complete}->() if exists $subscriber->{complete};
+                },
+            };
+
+            $source->subscribe($own_subscriber);
+
+            return;
+        });
+    };
+}
+
 sub op_delay {
     my ($delay) = @_;
 
